  subroutine rdchehab_kaolinite(nopr,iout,indir,outdir,lstrn,iset,&
  lset,llset,nlines,wcm,wavelength,rndat,ridat,iwave)

! ****
! param1.inc gives the maximum size of indices and extinction vectors
  include 'param1.inc'

! ****
! See rdinoutdir.f90
  character(len=60) :: indir,outdir
  integer :: nopr,iout,iset

! See main.f90
  integer :: nlines,iwave
  real :: wcm(nwavemax),wavelength(nwavemax)
  real :: rndat(nwavemax),ridat(nwavemax)
  character(len=100) :: lstrn,lset
  character(len=110) :: filnm

! Used here
  integer,parameter :: ndat=8465
  integer :: noprf
  real :: wcmdat(ndat),wavedat(ndat),rnval(ndat),rival(ndat)
  character(len=60) :: fil
  character(len=16) :: llset

! ***
! Read in the data from the ascii file
   lset=lstrn

!       '1234567890123456'
  llset='Chehab kaolinite'

! ***
! The input ascii file
!     '123456789012345678901234567890'123456789012345678901234567890'
  fil='single_files/chehab_kaolinite.dat                            '
   noprf=1
  call getfilnm(noprf,iout,fil,indir,filnm)
  if (noprf .eq. 1) then  
!  stop
  end if

! *****

! Data: Real and imaginary indices of kaolinite
! from 216 to 40000 cm-1

! Reference: Chehab M, Herbin H, Deguine A, Gosselin S, Bizet V
! Petitprez D
! First complex refractive indices retrieval from FIR to UV
! Application to kaolinite particles
! Aerosol Science and Technology, 2024;58(5):498

! Email contact person: M. Chehab (maria.chehab@univ-lille.fr)

! Format: 8465 real indices (2x,f8.2,2x,f10.4,1(2x,f5.3))
!         8465 imaginary indices (2x,f8.2,2x,f10.4,1(1x,e10.3))

!   cm-1       microns        real indices
!                       kaolinite
!   216.00     46.2963  3.712
!   217.00     46.0830  1.802
!   218.00     45.8716  1.806

! *****
! Read in the data

! Input ascii file
   idat=35
  open(idat,form='formatted',file=filnm,status='unknown')

  do i=1,17
   read(idat,fmt=100) header
  end do
  100 format(a80)

   nlines=ndat

   do i=1,nlines
    read(idat,*) wcmdat(i),wavedat(i),rnval(i)
   end do

  do i=1,3
   read(idat,fmt=100) header
  end do

   do i=1,nlines
    read(idat,*) wcmdat(i),wavedat(i),rival(i)
   end do

  close (idat)

! *****
! Put values into the output arrays
  do i=1,nlines
   wcm(i)=wcmdat(i)
   wavelength(i)=wavedat(i)
   rndat(i)=rnval(i)
   ridat(i)=rival(i)
  end do

! *****
  if (nopr .eq. 1) then

   write(iout,fmt=200) nlines,fil
   200 format(/,2x,"rdchehab_kaolinite: nlines,fil",/,&
   2x,i4,2x,a60)
   write(iout,fmt=230)
   230 format(2x,"rdchehab_kaolinite.f90d: i,wcm,wavelength,rndat and ridat")
   do i=1,nlines
    write(iout,fmt=240) i,wcm(i),wavelength(i),rndat(i),ridat(i)
    240 format(2x,i4,1p,2(1x,e10.3),2x,2(1x,e10.3))
   end do

  end if

! ******
  return
  end
